@@ -11,7 +11,7 @@ pub(crate) use std::{
   mem,
   ops::{Index, Range, RangeInclusive},
   path::{Path, PathBuf},
-  process::{self, Command, Stdio},
+  process::{self, Command, ExitStatus, Stdio},
   rc::Rc,
   str::{self, Chars},
   sync::{Mutex, MutexGuard},
@@ -25,48 +25,50 @@ pub(crate) use edit_distance::edit_distance;
 pub(crate) use lexiclean::Lexiclean;
 pub(crate) use libc::EXIT_FAILURE;
 pub(crate) use log::{info, warn};
+pub(crate) use regex::Regex;
 pub(crate) use snafu::{ResultExt, Snafu};
 pub(crate) use strum::{Display, EnumString, IntoStaticStr};
+pub(crate) use typed_arena::Arena;
 pub(crate) use unicode_width::{UnicodeWidthChar, UnicodeWidthStr};
 
 // modules
-pub(crate) use crate::{config_error, setting};
+pub(crate) use crate::{completions, config, config_error, setting};
 
 // functions
 pub(crate) use crate::{load_dotenv::load_dotenv, output::output, unindent::unindent};
 
 // traits
 pub(crate) use crate::{
-  command_ext::CommandExt, error::Error, error_result_ext::ErrorResultExt, keyed::Keyed,
-  ordinal::Ordinal, platform_interface::PlatformInterface, range_ext::RangeExt,
+  color_display::ColorDisplay, command_ext::CommandExt, keyed::Keyed, ordinal::Ordinal,
+  platform_interface::PlatformInterface, range_ext::RangeExt,
 };
 
 // structs and enums
 pub(crate) use crate::{
   alias::Alias, analyzer::Analyzer, assignment::Assignment,
-  assignment_resolver::AssignmentResolver, binding::Binding, color::Color,
-  compilation_error::CompilationError, compilation_error_kind::CompilationErrorKind,
-  config::Config, config_error::ConfigError, count::Count, delimiter::Delimiter,
-  dependency::Dependency, enclosure::Enclosure, evaluator::Evaluator, expression::Expression,
-  fragment::Fragment, function::Function, function_context::FunctionContext,
-  interrupt_guard::InterruptGuard, interrupt_handler::InterruptHandler, item::Item,
-  justfile::Justfile, keyword::Keyword, lexer::Lexer, line::Line, list::List,
-  load_error::LoadError, module::Module, name::Name, output_error::OutputError,
+  assignment_resolver::AssignmentResolver, ast::Ast, binding::Binding, color::Color,
+  compile_error::CompileError, compile_error_kind::CompileErrorKind,
+  conditional_operator::ConditionalOperator, config::Config, config_error::ConfigError,
+  count::Count, delimiter::Delimiter, dependency::Dependency, enclosure::Enclosure, error::Error,
+  evaluator::Evaluator, expression::Expression, fragment::Fragment, function::Function,
+  function_context::FunctionContext, interrupt_guard::InterruptGuard,
+  interrupt_handler::InterruptHandler, item::Item, justfile::Justfile, keyword::Keyword,
+  lexer::Lexer, line::Line, list::List, loader::Loader, name::Name, output_error::OutputError,
   parameter::Parameter, parameter_kind::ParameterKind, parser::Parser, platform::Platform,
   position::Position, positional::Positional, recipe::Recipe, recipe_context::RecipeContext,
-  recipe_resolver::RecipeResolver, runtime_error::RuntimeError, scope::Scope, search::Search,
-  search_config::SearchConfig, search_error::SearchError, set::Set, setting::Setting,
-  settings::Settings, shebang::Shebang, show_whitespace::ShowWhitespace, string_kind::StringKind,
-  string_literal::StringLiteral, subcommand::Subcommand, suggestion::Suggestion, table::Table,
-  thunk::Thunk, token::Token, token_kind::TokenKind, unresolved_dependency::UnresolvedDependency,
+  recipe_resolver::RecipeResolver, scope::Scope, search::Search, search_config::SearchConfig,
+  search_error::SearchError, set::Set, setting::Setting, settings::Settings, shebang::Shebang,
+  show_whitespace::ShowWhitespace, string_kind::StringKind, string_literal::StringLiteral,
+  subcommand::Subcommand, suggestion::Suggestion, table::Table, thunk::Thunk, token::Token,
+  token_kind::TokenKind, unresolved_dependency::UnresolvedDependency,
   unresolved_recipe::UnresolvedRecipe, use_color::UseColor, variables::Variables,
   verbosity::Verbosity, warning::Warning,
 };
 
 // type aliases
-pub(crate) type CompilationResult<'a, T> = Result<T, CompilationError<'a>>;
+pub(crate) type CompileResult<'a, T> = Result<T, CompileError<'a>>;
 pub(crate) type ConfigResult<T> = Result<T, ConfigError>;
-pub(crate) type RunResult<'a, T> = Result<T, RuntimeError<'a>>;
+pub(crate) type RunResult<'a, T> = Result<T, Error<'a>>;
 pub(crate) type SearchResult<T> = Result<T, SearchError>;
 
 // modules used in tests
