@@ -13,27 +13,27 @@ use TokenKind::*;
 /// bad.
 pub(crate) struct Lexer<'src> {
   /// Source text
-  src:                 &'src str,
+  src: &'src str,
   /// Char iterator
-  chars:               Chars<'src>,
+  chars: Chars<'src>,
   /// Tokens
-  tokens:              Vec<Token<'src>>,
+  tokens: Vec<Token<'src>>,
   /// Current token start
-  token_start:         Position,
+  token_start: Position,
   /// Current token end
-  token_end:           Position,
+  token_end: Position,
   /// Next character to be lexed
-  next:                Option<char>,
+  next: Option<char>,
   /// Next indent will start a recipe body
   recipe_body_pending: bool,
   /// Inside recipe body
-  recipe_body:         bool,
+  recipe_body: bool,
   /// Indentation stack
-  indentation:         Vec<&'src str>,
+  indentation: Vec<&'src str>,
   /// Interpolation token start stack
   interpolation_stack: Vec<Token<'src>>,
   /// Current open delimiters
-  open_delimiters:     Vec<(Delimiter, usize)>,
+  open_delimiters: Vec<(Delimiter, usize)>,
 }
 
 impl<'src> Lexer<'src> {
@@ -50,7 +50,7 @@ impl<'src> Lexer<'src> {
     let start = Position {
       offset: 0,
       column: 0,
-      line:   0,
+      line: 0,
     };
 
     Lexer {
@@ -86,7 +86,7 @@ impl<'src> Lexer<'src> {
         self.next = self.chars.next();
 
         Ok(())
-      },
+      }
       None => Err(self.internal_error("Lexer advanced past end of text")),
     }
   }
@@ -202,12 +202,12 @@ impl<'src> Lexer<'src> {
   fn internal_error(&self, message: impl Into<String>) -> CompileError<'src> {
     // Use `self.token_end` as the location of the error
     let token = Token {
-      src:    self.src,
+      src: self.src,
       offset: self.token_end.offset,
-      line:   self.token_end.line,
+      line: self.token_end.line,
       column: self.token_end.column,
       length: 0,
-      kind:   Unspecified,
+      kind: Unspecified,
     };
     CompileError {
       kind: CompileErrorKind::Internal {
@@ -226,11 +226,12 @@ impl<'src> Lexer<'src> {
       UnterminatedString | UnterminatedBacktick => {
         let kind = match StringKind::from_token_start(self.lexeme()) {
           Some(kind) => kind,
-          None =>
-            return self.internal_error("Lexer::error: expected string or backtick token start"),
+          None => {
+            return self.internal_error("Lexer::error: expected string or backtick token start")
+          }
         };
         kind.delimiter().len()
-      },
+      }
       // highlight the full token
       _ => self.lexeme().len(),
     };
@@ -250,18 +251,13 @@ impl<'src> Lexer<'src> {
   fn unterminated_interpolation_error(interpolation_start: Token<'src>) -> CompileError<'src> {
     CompileError {
       token: interpolation_start,
-      kind:  UnterminatedInterpolation,
+      kind: UnterminatedInterpolation,
     }
   }
 
   /// True if `text` could be an identifier
   pub(crate) fn is_identifier(text: &str) -> bool {
-    if !text
-      .chars()
-      .next()
-      .map(Self::is_identifier_start)
-      .unwrap_or(false)
-    {
+    if !text.chars().next().map_or(false, Self::is_identifier_start) {
       return false;
     }
 
@@ -304,7 +300,7 @@ impl<'src> Lexer<'src> {
           } else {
             self.lex_normal(first)?;
           };
-        },
+        }
         None => break,
       }
     }
@@ -411,7 +407,7 @@ impl<'src> Lexer<'src> {
         };
 
         Ok(())
-      },
+      }
       Continue => {
         if !self.indentation().is_empty() {
           for _ in self.indentation().chars() {
@@ -422,7 +418,7 @@ impl<'src> Lexer<'src> {
         }
 
         Ok(())
-      },
+      }
       Decrease => {
         while self.indentation() != whitespace {
           self.lex_dedent();
@@ -437,14 +433,14 @@ impl<'src> Lexer<'src> {
         }
 
         Ok(())
-      },
+      }
       Mixed { whitespace } => {
         for _ in whitespace.chars() {
           self.advance()?;
         }
 
         Err(self.error(MixedLeadingWhitespace { whitespace }))
-      },
+      }
       Inconsistent => {
         for _ in whitespace.chars() {
           self.advance()?;
@@ -452,9 +448,9 @@ impl<'src> Lexer<'src> {
 
         Err(self.error(InconsistentLeadingWhitespace {
           expected: self.indentation(),
-          found:    whitespace,
+          found: whitespace,
         }))
-      },
+      }
       Increase => {
         while self.next_is_whitespace() {
           self.advance()?;
@@ -472,39 +468,37 @@ impl<'src> Lexer<'src> {
         }
 
         Ok(())
-      },
+      }
     }
   }
 
   /// Lex token beginning with `start` outside of a recipe body
   fn lex_normal(&mut self, start: char) -> CompileResult<'src, ()> {
     match start {
-      '&' => self.lex_digraph('&', '&', AmpersandAmpersand),
+      ' ' | '\t' => self.lex_whitespace(),
       '!' => self.lex_digraph('!', '=', BangEquals),
-      '*' => self.lex_single(Asterisk),
+      '#' => self.lex_comment(),
       '$' => self.lex_single(Dollar),
-      '@' => self.lex_single(At),
-      '[' => self.lex_delimiter(BracketL),
-      ']' => self.lex_delimiter(BracketR),
-      '=' => self.lex_choice('=', EqualsEquals, Equals),
-      ',' => self.lex_single(Comma),
-      ':' => self.lex_colon(),
+      '&' => self.lex_digraph('&', '&', AmpersandAmpersand),
       '(' => self.lex_delimiter(ParenL),
       ')' => self.lex_delimiter(ParenR),
+      '*' => self.lex_single(Asterisk),
+      '+' => self.lex_single(Plus),
+      ',' => self.lex_single(Comma),
+      ':' => self.lex_colon(),
+      '=' => self.lex_choices('=', &[('=', EqualsEquals), ('~', EqualsTilde)], Equals),
+      '@' => self.lex_single(At),
+      '[' => self.lex_delimiter(BracketL),
+      '\n' | '\r' => self.lex_eol(),
+      ']' => self.lex_delimiter(BracketR),
+      '`' | '"' | '\'' => self.lex_string(),
       '{' => self.lex_delimiter(BraceL),
       '}' => self.lex_delimiter(BraceR),
-      '+' => self.lex_single(Plus),
-      '#' => self.lex_comment(),
-      ' ' => self.lex_whitespace(),
-      '`' | '"' | '\'' => self.lex_string(),
-      '\n' => self.lex_eol(),
-      '\r' => self.lex_eol(),
-      '\t' => self.lex_whitespace(),
       _ if Self::is_identifier_start(start) => self.lex_identifier(),
       _ => {
         self.advance()?;
         Err(self.error(UnknownStartOfToken))
-      },
+      }
     }
   }
 
@@ -585,7 +579,7 @@ impl<'src> Lexer<'src> {
           .interpolation_stack
           .push(self.tokens[self.tokens.len() - 1]);
         Ok(())
-      },
+      }
       EndOfFile => Ok(()),
     }
   }
@@ -616,20 +610,23 @@ impl<'src> Lexer<'src> {
   /// Lex a double-character token of kind `then` if the second character of
   /// that token would be `second`, otherwise lex a single-character token of
   /// kind `otherwise`
-  fn lex_choice(
+  fn lex_choices(
     &mut self,
-    second: char,
-    then: TokenKind,
+    first: char,
+    choices: &[(char, TokenKind)],
     otherwise: TokenKind,
   ) -> CompileResult<'src, ()> {
-    self.advance()?;
+    self.presume(first)?;
 
-    if self.accepted(second)? {
-      self.token(then);
-    } else {
-      self.token(otherwise);
+    for (second, then) in choices {
+      if self.accepted(*second)? {
+        self.token(*then);
+        return Ok(());
+      }
     }
 
+    self.token(otherwise);
+
     Ok(())
   }
 
@@ -644,11 +641,12 @@ impl<'src> Lexer<'src> {
       BracketR => self.close_delimiter(Bracket)?,
       ParenL => self.open_delimiter(Paren),
       ParenR => self.close_delimiter(Paren)?,
-      _ =>
+      _ => {
         return Err(self.internal_error(format!(
           "Lexer::lex_delimiter called with non-delimiter token: `{}`",
           kind,
-        ))),
+        )))
+      }
     }
 
     // Emit the delimiter token
@@ -935,6 +933,7 @@ mod tests {
       Eol => "\n",
       Equals => "=",
       EqualsEquals => "==",
+      EqualsTilde => "=~",
       Indent => "  ",
       InterpolationEnd => "}}",
       InterpolationStart => "{{",
@@ -947,8 +946,9 @@ mod tests {
       Dedent | Eof => "",
 
       // Variable lexemes
-      Text | StringToken | Backtick | Identifier | Comment | Unspecified =>
-        panic!("Token {:?} has no default lexeme", kind),
+      Text | StringToken | Backtick | Identifier | Comment | Unspecified => {
+        panic!("Token {:?} has no default lexeme", kind)
+      }
     }
   }
 
@@ -992,7 +992,7 @@ mod tests {
           kind,
         };
         assert_eq!(have, want);
-      },
+      }
     }
   }
 
@@ -2058,7 +2058,7 @@ mod tests {
 
   error! {
     name:   tokenize_unknown,
-    input:  "~",
+    input:  "%",
     offset: 0,
     line:   0,
     column: 0,
@@ -2117,16 +2117,6 @@ mod tests {
     kind:   UnpairedCarriageReturn,
   }
 
-  error! {
-    name:   unknown_start_of_token_tilde,
-    input:  "~",
-    offset: 0,
-    line:   0,
-    column: 0,
-    width:  1,
-    kind:   UnknownStartOfToken,
-  }
-
   error! {
     name:   invalid_name_start_dash,
     input:  "-foo",
