@@ -1,43 +1,14 @@
-#![deny(clippy::all, clippy::pedantic, clippy::restriction)]
+#![deny(clippy::all, clippy::pedantic)]
 #![allow(
-  clippy::blanket_clippy_restriction_lints,
-  clippy::comparison_chain,
-  clippy::create_dir,
-  clippy::default_numeric_fallback,
-  clippy::else_if_without_else,
   clippy::enum_glob_use,
-  clippy::exhaustive_enums,
-  clippy::exhaustive_structs,
-  clippy::expect_used,
-  clippy::filter_map,
   clippy::if_not_else,
-  clippy::implicit_return,
-  clippy::indexing_slicing,
-  clippy::integer_arithmetic,
-  clippy::let_underscore_must_use,
-  clippy::map_unwrap_or,
-  clippy::match_same_arms,
-  clippy::missing_docs_in_private_items,
   clippy::missing_errors_doc,
-  clippy::missing_inline_in_public_items,
   clippy::needless_lifetimes,
   clippy::needless_pass_by_value,
   clippy::non_ascii_literal,
-  clippy::option_if_let_else,
-  clippy::panic,
-  clippy::panic_in_result_fn,
-  clippy::pattern_type_mismatch,
-  clippy::print_stdout,
   clippy::shadow_unrelated,
-  clippy::string_add,
   clippy::struct_excessive_bools,
   clippy::too_many_lines,
-  clippy::unnecessary_wraps,
-  clippy::unreachable,
-  clippy::unwrap_in_result,
-  clippy::unwrap_used,
-  clippy::use_debug,
-  clippy::wildcard_enum_match_arm,
   clippy::wildcard_imports
 )]
 
@@ -72,6 +43,7 @@ mod compile_error;
 mod compile_error_kind;
 mod compiler;
 mod completions;
+mod conditional_operator;
 mod config;
 mod config_error;
 mod count;
