@@ -10,16 +10,16 @@ pub(crate) enum Setting<'src> {
 
 #[derive(Debug, Clone, PartialEq)]
 pub(crate) struct Shell<'src> {
-  pub(crate) command:   StringLiteral<'src>,
+  pub(crate) command: StringLiteral<'src>,
   pub(crate) arguments: Vec<StringLiteral<'src>>,
 }
 
 impl<'src> Display for Setting<'src> {
   fn fmt(&self, f: &mut Formatter) -> Result<(), fmt::Error> {
     match self {
-      Setting::DotenvLoad(value) => write!(f, "{}", value),
-      Setting::Export(value) => write!(f, "{}", value),
-      Setting::PositionalArguments(value) => write!(f, "{}", value),
+      Setting::DotenvLoad(value) | Setting::Export(value) | Setting::PositionalArguments(value) => {
+        write!(f, "{}", value)
+      }
       Setting::Shell(shell) => write!(f, "{}", shell),
     }
   }
