@@ -18,9 +18,9 @@ use crate::compiler::Compiler;
 
 mod full {
   pub(crate) use crate::{
-    assignment::Assignment, dependency::Dependency, expression::Expression, fragment::Fragment,
-    justfile::Justfile, line::Line, parameter::Parameter, parameter_kind::ParameterKind,
-    recipe::Recipe, thunk::Thunk,
+    assignment::Assignment, conditional_operator::ConditionalOperator, dependency::Dependency,
+    expression::Expression, fragment::Fragment, justfile::Justfile, line::Line,
+    parameter::Parameter, parameter_kind::ParameterKind, recipe::Recipe, thunk::Thunk,
   };
 }
 
@@ -36,7 +36,7 @@ pub fn summary(path: &Path) -> Result<Result<Summary, String>, io::Error> {
 #[derive(Eq, PartialEq, Hash, Ord, PartialOrd, Debug, Clone)]
 pub struct Summary {
   pub assignments: BTreeMap<String, Assignment>,
-  pub recipes:     BTreeMap<String, Recipe>,
+  pub recipes: BTreeMap<String, Recipe>,
 }
 
 impl Summary {
@@ -51,7 +51,7 @@ impl Summary {
     }
 
     Summary {
-      recipes:     justfile
+      recipes: justfile
         .recipes
         .into_iter()
         .map(|(name, recipe)| {
@@ -72,13 +72,13 @@ impl Summary {
 
 #[derive(Eq, PartialEq, Hash, Ord, PartialOrd, Debug, Clone)]
 pub struct Recipe {
-  pub aliases:      Vec<String>,
+  pub aliases: Vec<String>,
   pub dependencies: Vec<Dependency>,
-  pub lines:        Vec<Line>,
-  pub private:      bool,
-  pub quiet:        bool,
-  pub shebang:      bool,
-  pub parameters:   Vec<Parameter>,
+  pub lines: Vec<Line>,
+  pub private: bool,
+  pub quiet: bool,
+  pub shebang: bool,
+  pub parameters: Vec<Parameter>,
 }
 
 impl Recipe {
@@ -101,16 +101,16 @@ impl Recipe {
 
 #[derive(Eq, PartialEq, Hash, Ord, PartialOrd, Debug, Clone)]
 pub struct Parameter {
-  pub kind:    ParameterKind,
-  pub name:    String,
+  pub kind: ParameterKind,
+  pub name: String,
   pub default: Option<Expression>,
 }
 
 impl Parameter {
   fn new(parameter: &full::Parameter) -> Parameter {
     Parameter {
-      kind:    ParameterKind::new(parameter.kind),
-      name:    parameter.name.lexeme().to_owned(),
+      kind: ParameterKind::new(parameter.kind),
+      name: parameter.name.lexeme().to_owned(),
       default: parameter.default.as_ref().map(Expression::new),
     }
   }
@@ -167,14 +167,14 @@ impl Fragment {
 
 #[derive(Eq, PartialEq, Hash, Ord, PartialOrd, Debug, Clone)]
 pub struct Assignment {
-  pub exported:   bool,
+  pub exported: bool,
   pub expression: Expression,
 }
 
 impl Assignment {
   fn new(assignment: &full::Assignment) -> Assignment {
     Assignment {
-      exported:   assignment.export,
+      exported: assignment.export,
       expression: Expression::new(&assignment.value),
     }
   }
@@ -186,7 +186,7 @@ pub enum Expression {
     command: String,
   },
   Call {
-    name:      String,
+    name: String,
     arguments: Vec<Expression>,
   },
   Concatination {
@@ -194,11 +194,11 @@ pub enum Expression {
     rhs: Box<Expression>,
   },
   Conditional {
-    lhs:       Box<Expression>,
-    rhs:       Box<Expression>,
-    then:      Box<Expression>,
+    lhs: Box<Expression>,
+    rhs: Box<Expression>,
+    then: Box<Expression>,
     otherwise: Box<Expression>,
-    inverted:  bool,
+    operator: ConditionalOperator,
   },
   String {
     text: String,
@@ -217,17 +217,17 @@ impl Expression {
       },
       Call { thunk } => match thunk {
         full::Thunk::Nullary { name, .. } => Expression::Call {
-          name:      name.lexeme().to_owned(),
+          name: name.lexeme().to_owned(),
           arguments: Vec::new(),
         },
         full::Thunk::Unary { name, arg, .. } => Expression::Call {
-          name:      name.lexeme().to_owned(),
+          name: name.lexeme().to_owned(),
           arguments: vec![Expression::new(arg)],
         },
         full::Thunk::Binary {
           name, args: [a, b], ..
         } => Expression::Call {
-          name:      name.lexeme().to_owned(),
+          name: name.lexeme().to_owned(),
           arguments: vec![Expression::new(a), Expression::new(b)],
         },
         full::Thunk::Ternary {
@@ -235,7 +235,7 @@ impl Expression {
           args: [a, b, c],
           ..
         } => Expression::Call {
-          name:      name.lexeme().to_owned(),
+          name: name.lexeme().to_owned(),
           arguments: vec![Expression::new(a), Expression::new(b), Expression::new(c)],
         },
       },
@@ -245,16 +245,16 @@ impl Expression {
       },
       Conditional {
         lhs,
-        rhs,
-        inverted,
-        then,
+        operator,
         otherwise,
+        rhs,
+        then,
       } => Expression::Conditional {
-        lhs:       Box::new(Expression::new(lhs)),
-        rhs:       Box::new(Expression::new(rhs)),
-        then:      Box::new(Expression::new(then)),
+        lhs: Box::new(Expression::new(lhs)),
+        operator: ConditionalOperator::new(*operator),
         otherwise: Box::new(Expression::new(otherwise)),
-        inverted:  *inverted,
+        rhs: Box::new(Expression::new(rhs)),
+        then: Box::new(Expression::new(then)),
       },
       StringLiteral { string_literal } => Expression::String {
         text: string_literal.cooked.clone(),
@@ -267,16 +267,33 @@ impl Expression {
   }
 }
 
+#[derive(Eq, PartialEq, Hash, Ord, PartialOrd, Debug, Clone)]
+pub enum ConditionalOperator {
+  Equality,
+  Inequality,
+  RegexMatch,
+}
+
+impl ConditionalOperator {
+  fn new(operator: full::ConditionalOperator) -> Self {
+    match operator {
+      full::ConditionalOperator::Equality => Self::Equality,
+      full::ConditionalOperator::Inequality => Self::Inequality,
+      full::ConditionalOperator::RegexMatch => Self::RegexMatch,
+    }
+  }
+}
+
 #[derive(Eq, PartialEq, Hash, Ord, PartialOrd, Debug, Clone)]
 pub struct Dependency {
-  pub recipe:    String,
+  pub recipe: String,
   pub arguments: Vec<Expression>,
 }
 
 impl Dependency {
-  fn new(dependency: &full::Dependency) -> Dependency {
-    Dependency {
-      recipe:    dependency.recipe.name().to_owned(),
+  fn new(dependency: &full::Dependency) -> Self {
+    Self {
+      recipe: dependency.recipe.name().to_owned(),
       arguments: dependency.arguments.iter().map(Expression::new).collect(),
     }
   }
