@@ -4,27 +4,27 @@ use crate::common::*;
 #[derivative(Debug, Clone, PartialEq = "feature_allow_slow_enum")]
 pub(crate) enum Thunk<'src> {
   Nullary {
-    name:     Name<'src>,
+    name: Name<'src>,
     #[derivative(Debug = "ignore", PartialEq = "ignore")]
     function: fn(&FunctionContext) -> Result<String, String>,
   },
   Unary {
-    name:     Name<'src>,
+    name: Name<'src>,
     #[derivative(Debug = "ignore", PartialEq = "ignore")]
     function: fn(&FunctionContext, &str) -> Result<String, String>,
-    arg:      Box<Expression<'src>>,
+    arg: Box<Expression<'src>>,
   },
   Binary {
-    name:     Name<'src>,
+    name: Name<'src>,
     #[derivative(Debug = "ignore", PartialEq = "ignore")]
     function: fn(&FunctionContext, &str, &str) -> Result<String, String>,
-    args:     [Box<Expression<'src>>; 2],
+    args: [Box<Expression<'src>>; 2],
   },
   Ternary {
-    name:     Name<'src>,
+    name: Name<'src>,
     #[derivative(Debug = "ignore", PartialEq = "ignore")]
     function: fn(&FunctionContext, &str, &str, &str) -> Result<String, String>,
-    args:     [Box<Expression<'src>>; 3],
+    args: [Box<Expression<'src>>; 3],
   },
 }
 
@@ -33,8 +33,11 @@ impl<'src> Thunk<'src> {
     name: Name<'src>,
     mut arguments: Vec<Expression<'src>>,
   ) -> CompileResult<'src, Thunk<'src>> {
-    if let Some(function) = crate::function::TABLE.get(&name.lexeme()) {
-      match (function, arguments.len()) {
+    crate::function::TABLE.get(&name.lexeme()).map_or(
+      Err(name.error(CompileErrorKind::UnknownFunction {
+        function: name.lexeme(),
+      })),
+      |function| match (function, arguments.len()) {
         (Function::Nullary(function), 0) => Ok(Thunk::Nullary {
           function: *function,
           name,
@@ -52,7 +55,7 @@ impl<'src> Thunk<'src> {
             args: [a, b],
             name,
           })
-        },
+        }
         (Function::Ternary(function), 3) => {
           let c = Box::new(arguments.pop().unwrap());
           let b = Box::new(arguments.pop().unwrap());
@@ -62,18 +65,14 @@ impl<'src> Thunk<'src> {
             args: [a, b, c],
             name,
           })
-        },
+        }
         _ => Err(name.error(CompileErrorKind::FunctionArgumentCountMismatch {
           function: name.lexeme(),
-          found:    arguments.len(),
+          found: arguments.len(),
           expected: function.argc(),
         })),
-      }
-    } else {
-      Err(name.error(CompileErrorKind::UnknownFunction {
-        function: name.lexeme(),
-      }))
-    }
+      },
+    )
   }
 }
 
